@@ -14,6 +14,8 @@ def load_dataset(sc, name, read_all, input_dest='', header=True):
     # read_all -> True to read all data, False to read 'input_columns' in 'args'
 
     data_storage = get_dataset_property(name=name, prop='storage_type')
+    if data_storage is None:
+        data_storage = "FileSystem"
     module_name = data_storage.split('-')[0].lower()
 
     class_ = get_class(module_name)
