@@ -8,21 +8,13 @@ class Hive(DataStorage):
     # overriding abstract method
     def load_dataset(self, name, read_all=True, input_dest='', header=True):
 
-        input_columns = get_dataset_property(name, "input-columns")
+        input_columns = get_dataset_property(name, "input_columns")
 
         if input_dest == '':
             input_dataset = get_dataset_property(name)
         else:
             input_dataset = input_dest
 
-        # # To manage supervised algorithms
-        # if "labelCol" in self.args:
-        #     label_col = self.args["labelCol"]
-        #     columns_list = input_columns.split(",")
-        #     if label_col not in columns_list:
-        #         columns_list.append(label_col)
-        #     input_columns = ','.join(columns_list)
-
         if read_all:
             df = self.spark.sql("SELECT * FROM " + input_dataset)
         else:
