@@ -3,12 +3,12 @@ from .utils import get_dataset_property
 
 class Mongo(DataStorage):
 
-    def __init__(self, args):
-        super().__init__(args)
-        user = self.args['mongoUser']
-        password = self.args['mongoPassword']
-        ip = self.args['mongoUri'].split(":")[0] 
-        port = self.args['mongoUri'].split(":")[1] 
+    def __init__(self):
+        super().__init__()
+        user = get_dataset_property('mongoUser')
+        password = get_dataset_property('mongoPassword')
+        ip = get_dataset_property('mongoUri').split(":")[0] 
+        port = get_dataset_property('mongoUri').split(":")[1] 
         self.uri = "mongodb://" + user + ":" + password + "@" + ip + ":" + port + "/"
 
 
@@ -16,7 +16,7 @@ class Mongo(DataStorage):
     def load_dataset(self, name, read_all=True, input_dest=None, header=True):
 
         if input_dest is None:
-            input_dest = self.args["input-dataset"]
+            input_dest = get_dataset_property("input-dataset")
    
         db = input_dest.split["."][0]
         collection = input_dest.split["."][1]
@@ -31,7 +31,7 @@ class Mongo(DataStorage):
     def save_dataset(self, name, df, output_dest=None):
 
         if output_dest is None:
-            output_dest = self.args["output-dataset"]
+            output_dest = get_dataset_property("output-dataset")
        
         db = output_dest.split["."][0]
         collection = output_dest.split["."][1]
